@@ -43,6 +43,7 @@ import urllib3
 import getpass
 import shutil
 import stat
+import urllib.parse
 
 import logging
 
@@ -67,7 +68,7 @@ import logging
 #  Copy 'run.py' and 'settings.ini' files wherever you want to have your record repository.
 #  Windows let's you double click 'run.py'. Can run from desktop.
 # Magic number 42 is used to connect to all radios found in 'settings.ini'.
-print('0.6.68')
+print('0.6.8')
 
 # https://www.scrapehero.com/how-to-fake-and-rotate-user-agents-using-python-3/
 proxy_support = urllib.request.ProxyHandler({})
@@ -525,7 +526,7 @@ class GRecorder:
     @staticmethod  # copy keep-alive timeout=3000
     def thread_pull_song_name(url, ini_key):
         # print(f' thread_pull_song_name: {ini_key}')
-        update_terminal = False
+        update_terminal = ''.encode('utf-8')
         stream_song_name = GRecorder.current_song_dict[ini_key]
         GIni.fail_meta_dict[url] = 'False'
         headers = {'Connection': 'keep-alive'}
@@ -563,9 +564,18 @@ class GRecorder:
 
                 if not update_terminal == stream_song_name:
                     update_terminal = stream_song_name
-                    print('\t\t title on ' + ini_key + ':\t' + update_terminal)
-            # give recorder command to record, we got a match from search
-            # GIni.search_title_keys_list.append(42)     # test value
+                    try:
+                        print('\t\t title on ' + ini_key + ':\t' + update_terminal)
+                        # see what happens. looks like a unit test case
+                    except UnicodeEncodeError:
+                        print('\t\t title on ' + ini_key + ':\t' + 'unicode error (check "locale" settings)')
+                    except Exception as ex:
+                        print('\t\t title on ' + ini_key + ':\t' + 'unknown error (print to your terminal)')
+                        print(ex)
+                    else:
+                        pass
+            # give recorder command to record, if we got a match from search gui
+            #
             try:
                 for _ in GIni.search_title_keys_list:
                     if _ == ini_key:
@@ -874,7 +884,7 @@ class GRecorder:
 
                 if time() - old_time > rand_short:
                     old_time = time()
-                    rh = response.headers
+                    rh = response.headers   # keep conn. alive
                     # print(response.headers)
 
                 if time() - old_time > rand_long:  # new connection
