@@ -489,6 +489,7 @@ class GhettoLanguage(UIWindow):
         ' Das Radio spielt den Titel mit dem Wort, die Aufnahme startet und endet dann.',
         ' Bei Titelwechseln kann noch ein Teil des folgenden',
         ' Titels aufgenommen werden. Einfach löschen.',
+        ' Man kann mehr als eine "settings.ini" haben. Vielleicht eine "classic.ini"?',
         ' Die "Uhr" oben rechts, falls mal keine Zeit da ist "Stop" zu drücken.',
         ' Der Uhr ist wie eine Eieruhr. Nur in Stunden. Fertig! :)',
         ' Die Uhr kann man jederzeit ändern. Viel Spaß!',
@@ -501,6 +502,7 @@ class GhettoLanguage(UIWindow):
         ' Phrases like: Elvis Anthrax Heino concrete chamber music.',
         ' There is no rule for writing the words UPPER or lower case.',
         ' Radio station is playing a title with a search phrase! Record!',
+        ' You can have more than one "settings.ini". Perhaps a "classic.ini"?',
         ' A "Timer" in the upper right corner. If you do not like ',
         ' pressing the "Stop" button yourself. One can change the value',
         ' every time. Have fun!'
